@@ -271,7 +271,7 @@ class Downloader:
                 await self.download_file(url, referral=referral, filename=filename, session=session,
                                          show_progress=show_progress)
         except Exception:
-            await log(f"Error attempting {url}")
+            await log(f"\nError attempting {url}")
 
     async def download_all(self, album_obj: AlbumItem, session: DownloadSession, show_progress: bool = True) -> None:
         """Download the data from all given links and store them into corresponding files."""
@@ -284,6 +284,7 @@ class Downloader:
         """Download the content of all links and save them as files."""
         session = DownloadSession(self.client, conn_timeout)
         await self.download_all(self.album_obj, session, show_progress=show_progress)
+        await session.client_session.close()
         self.SQL_helper.conn.commit()
 
 
